@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::TravisYML;
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 # ABSTRACT: creates a .travis.yml file for Travis CI
 
 use Moose;
@@ -191,8 +191,10 @@ for a list of variables that can be used.
 =head2 perl_version
 
 This is a space-delimited option with a list of the perl versions to test against.  The default
-is all supported versions available within Travis.  You can restrict it down to only a few like
-this:
+is all supported versions available within Travis, except for Perl 5.8.  This is because there's
+still various DZIL plugins that require 5.10.  (This may change in the future.)
+
+You can restrict it down to only a few like this:
 
     perl_version = 5.10 5.12
 
@@ -258,7 +260,7 @@ for a list of phases.
 
 The positions determine if the commands are to be added at the beginning (C<<< pre_ >>>), the end (C<<< post_ >>>), or
 replacing (no prefix) the existing code.  Replace entire blocks at your own risk; TravisYML may change
-the blocks for bug fixes or new features.
+the original blocks for bug fixes or new features, and you wouldn't see them if they were replaced.
 
 The file type determines if these command changes are for the DZIL YML file (C<<< _dzil >>>), the build YML file
 (C<<< _build >>>), or both (no suffix).
